Commit: 0c9e47705d287dc7ce976059b7eb0e7b463b2b42
Author: Richard Antalik
Date:   Sun Apr 12 22:57:34 2020 +0200
Branches: master
https://developer.blender.org/rB0c9e47705d287dc7ce976059b7eb0e7b463b2b42

Fix T75421: Wipe clock and Iris transition not working.

Use enum items in RNA enum definition instead of hard-coded values.

Broken by 5dcb6fb22f3 Cleanup: unused enums

Reviewed By: brecht

Differential Revision: https://developer.blender.org/D7342

===================================================================

M       source/blender/makesrna/intern/rna_sequencer.c

===================================================================

diff --git a/source/blender/makesrna/intern/rna_sequencer.c 
b/source/blender/makesrna/intern/rna_sequencer.c
index f486456bd38..b135c962891 100644
--- a/source/blender/makesrna/intern/rna_sequencer.c
+++ b/source/blender/makesrna/intern/rna_sequencer.c
@@ -2517,12 +2517,12 @@ static void rna_def_wipe(StructRNA *srna)
   PropertyRNA *prop;
 
   static const EnumPropertyItem wipe_type_items[] = {
-      {0, "SINGLE", 0, "Single", ""},
-      {1, "DOUBLE", 0, "Double", ""},
-      /* not used yet {2, "BOX", 0, "Box", ""}, */
-      /* not used yet {3, "CROSS", 0, "Cross", ""}, */
-      {4, "IRIS", 0, "Iris", ""},
-      {5, "CLOCK", 0, "Clock", ""},
+      {DO_SINGLE_WIPE, "SINGLE", 0, "Single", ""},
+      {DO_DOUBLE_WIPE, "DOUBLE", 0, "Double", ""},
+      /* not used yet {DO_BOX_WIPE, "BOX", 0, "Box", ""}, */
+      /* not used yet {DO_CROSS_WIPE, "CROSS", 0, "Cross", ""}, */
+      {DO_IRIS_WIPE, "IRIS", 0, "Iris", ""},
+      {DO_CLOCK_WIPE, "CLOCK", 0, "Clock", ""},
       {0, NULL, 0, NULL, NULL},
   };

_______________________________________________
Bf-blender-cvs mailing list
[email protected]
https://lists.blender.org/mailman/listinfo/bf-blender-cvs

Reply via email to